Skip to contents

Collapse Handler Dependency Languages Element Plus can use for its built-in text

Usage

el_locales()

Value

A character vector of locale codes, such as "en" and "zh-TW", any of which can be passed as locale to el_page().

Examples

el_locales()
#>  [1] "af"    "ar"    "ar-eg" "az"    "bg"    "bn"    "ca"    "ckb"   "cs"   
#> [10] "da"    "de"    "el"    "en"    "eo"    "es"    "et"    "eu"    "fa"   
#> [19] "fi"    "fr"    "he"    "hi"    "hr"    "hu"    "hy-am" "id"    "it"   
#> [28] "ja"    "kk"    "km"    "ko"    "ku"    "ky"    "lo"    "lt"    "lv"   
#> [37] "mg"    "mn"    "ms"    "my"    "nb-no" "nl"    "no"    "pa"    "pl"   
#> [46] "pt"    "pt-br" "ro"    "ru"    "sk"    "sl"    "sr"    "sv"    "sw"   
#> [55] "ta"    "te"    "th"    "tk"    "tr"    "ug-cn" "uk"    "uz-uz" "vi"   
#> [64] "zh-cn" "zh-hk" "zh-mo" "zh-tw"